@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::KENTNL::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.5.1';
+  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.6.0';
 }
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
@@ -79,6 +79,7 @@ BEGIN {
   _mk_only(qw( cpan CPAN cpan ));
   _mk_only(qw( twitter TWITTER twitter ));
   _mk_only(qw( fiveten FIVETEN fiveten ));
+  _mk_only(qw( ghissues GHISSUES ghissues ));
 }
 
 sub _release_fail {
@@ -159,7 +160,7 @@ sub bundle_config_inner {
   my (@version) = ( [ 'Git::NextVersion' => { version_regexp => '^(.*)-source$', first_version => '0.1.0' } ], );
   my (@metadata) = (
     [ 'MetaConfig' => {} ],
-    _only_git( $arg, [ 'GithubMeta' => {} ] ),
+    _only_git( $arg, [ 'GithubMeta' => { _only_ghissues( $arg, issues => 1 ), } ] ),
     [ 'MetaProvides::Package' => {} ],
     [
       'MetaData::BuiltWith' => { $^O eq 'linux' ? ( show_uname => 1, uname_args => q{ -s -o -r -m -i } ) : (), show_config => 1 }
@@ -278,7 +279,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 1.5.1
+version 1.6.0
 
 =head1 SYNOPSIS
 
